      subroutine list_ccs (bin, ncol, nrow, idim1, idim2, nrot, nannuli,
     $     img, msk, r4_img, fft1, fft3, fft4, fft5, prj_rot, pprj, 
     $     pmap, fltpmap, img_num, xcen, ycen, xcen_model ,ycen_model,
     $     res_min, res_max, ann_lo ,ann_hi, radius, pixres_max,
     $     del_pixres, del_ang, cc_avg ,cc_res_global, cc_rad_global,
     $     verbose)
      
C     Computes and then lists correlation coefficients as a function of
C     particle radius and resolution
      
      implicit none
      
      integer, intent(in) :: bin, ncol, nrow, idim1, idim2, verbose
      integer, intent(in) :: nrot, nannuli, img_num, ann_lo, ann_hi
      real, intent(in)    :: del_ang, pixres_max, del_pixres
      real, intent(in)    :: res_min, res_max
      real, intent(in)    :: img(ncol,nrow), prj_rot(ncol,nrow)
      real, intent(in)    :: pmap(nrot,nannuli)
      real, intent(in)    :: radius, xcen, ycen, xcen_model, ycen_model
      complex, intent(in) :: fft3(idim1,idim2)
      
      real, intent(out)    :: msk(ncol,nrow), r4_img(ncol,nrow)
      complex, intent(out) :: fft4(idim1,idim2), fft5(idim1,idim2)
      real, intent(out)    :: pprj(nrot,nannuli)
      real, intent(out)    :: fltpmap(nrot,nannuli)
      
      complex, intent(inout) :: fft1(idim1,idim2)
      real, intent(inout)    :: cc_res_global(2,20), cc_avg
      real, intent(inout)    :: cc_rad_global(2,nannuli)
      
      integer i, j
      real ccres(2,20), ccrad(2,nannuli), sumrsq
      
      msk = img                 ! f90 array syntax
      call map_2dmask (msk, ncol, nrow, ann_lo, ann_hi, xcen, ycen)
      call map_fft_fill_ppft(msk, ncol, nrow, fft4, idim1, idim2)
      call fft_2d (fft4, idim1, idim2)
      
      msk = prj_rot             ! f90 array syntax
      call map_2dmask (msk, ncol, nrow, ann_lo, ann_hi, xcen_model,
     $     ycen_model)
      call map_fft_fill_ppft(msk, ncol, nrow, fft5, idim1, idim2)
      call fft_2d (fft5, idim1, idim2)
      
      call pftcc_res (fft1, fft3, fft4, fft5, idim1, idim2, ccres,
     $     del_pixres)
      
      if(res_min > 0.0) then
         call fft_hip (fft1, idim1, idim2, res_min, 0.0, .true.)
      endif
      if(res_max > 0.0) then
         call fft_lop (fft1, idim1, idim2, res_max, 0.0, .true.)
      endif
      
      call fft_2d_back(fft1, idim1, idim2)
      call fft_map_fill_ppft(fft1, idim1, idim2, r4_img, ncol, nrow)
      call map_polar (r4_img, ncol, nrow, fltpmap, nrot, nannuli, xcen,
     $     ycen, 1.0, radius, del_ang)
      call map_polar (prj_rot, ncol, nrow, pprj, nrot, nannuli, 
     1     xcen_model, ycen_model, 1.0, radius, del_ang)
      call cc_radii (pmap, fltpmap, pprj, nrot, nannuli, ann_hi, ccrad,
     $     verbose)
      
      sumrsq = 0.0
      do i = 1,ann_hi+1
         cc_rad_global(1,i) = cc_rad_global(1,i) + ccrad(1,i)
         cc_rad_global(2,i) = cc_rad_global(2,i) + ccrad(2,i)
         if(i >= ann_lo) then
            sumrsq = sumrsq + (bin*(i-1))**2
            cc_avg = cc_avg + ccrad(2,i)*((bin*(i-1))**2)
         endif
      enddo
c     xdy wants to track all radii with verbose == 1 
      if(verbose >= 1) then
         do i = ann_hi+1, nannuli
            cc_rad_global(1,i) = cc_rad_global(1,i) + ccrad(1,i)
            cc_rad_global(2,i) = cc_rad_global(2,i) + ccrad(2,i)
         enddo
      endif
      if(sumrsq > 0.0) then
         cc_avg = cc_avg/sumrsq
      else
         cc_avg = 0.0
      endif
      j = nint(1/(pixres_max*del_pixres))
      do i = 1,j
         cc_res_global(1,i) = cc_res_global(1,i) + ccres(1,i)
         cc_res_global(2,i) = cc_res_global(2,i) + ccres(2,i)
      enddo
crss      write (8,1000) img_num, (ccres(1,i),i=1,j)
crss      write(10,1000) img_num, (ccres(2,i),i=1,j)
crss      write (9,1010) ' ccs vs radius for particle', img_num
      do i = 1,ann_hi+1
         j = (i-1)*bin
crss        write (9,1020) j, ccrad(1,i), ccrad(2,i)
      enddo
crss      write (9,1030) cc_avg, ' = average cc for ann_lo,ann_hi=', 
crss     1 ann_lo, ann_hi
      
crss 1000      format(i6,20f7.3)
crss 1010      format(a,i6)
crss 1020      format(i5,2f10.3)
crss 1030      format(f7.3,a,2i4)
      
      return
      end subroutine list_ccs
      
